@@ -606,6 +606,12 @@ static gint getFillColorRGBA(GfxState *state)
 	  ((gint)(CLAMP (alpha, 0.0, 1.0) * 255.999)));
 }
 
+static gint lookupGlyph(GnomeFont *font, CharCode c, Unicode u)
+{
+  /* FIXME */
+  return gnome_font_lookup_default(font, u > 0 ? u : c);
+}
+
 // text drawing
 void GPOutputDev::drawString(GfxState *state, GString *s) /* FIXME */
 {
@@ -658,15 +664,12 @@ void GPOutputDev::drawString(GfxState *state, GString *s) /* FIXME */
     DBG (if (uLen > 1)
       g_warning("drawString: uLen > 1; p: %x", (gint)*p));
 
-    if (uLen == 1) {
-      gnome_glyphlist_glyph(ggl,
-			    /* FIXME */
-			    gnome_font_lookup_default(gnome_font, u[0]));
-      gnome_glyphlist_rmoveto(ggl, dx, dy);
+    gnome_glyphlist_glyph(ggl,
+			  lookupGlyph(gnome_font, code, uLen > 0 ? u[0] : 0));
+    gnome_glyphlist_rmoveto(ggl, dx, dy);
 
-      text_pos_x += dx;
-      text_pos_y += dy;
-    } /* else FIXME */
+    text_pos_x += dx;
+    text_pos_y += dy;
 
     p += n;
     len -= n;
