@@ -491,36 +491,28 @@ gpdf_control_properties_dialog_response_cb (GtkDialog *dialog, gint response_id,
 static gchar *
 gpdf_control_get_filename (BonoboControl *control)
 {
-	GPdfControlPrivate *priv; 
-	GtkWidget *fileselection;
-	GtkWidget *ok_button;
-	GtkWidget *cancel_button;
+	GtkWidget *filechooser;
 	gchar *pathname = NULL; 
 
-	fileselection = gtk_file_selection_new (_("Save a Copy"));
-	gtk_container_set_border_width (GTK_CONTAINER (fileselection), 10);
-	gtk_window_set_position (GTK_WINDOW (fileselection), GTK_WIN_POS_MOUSE);
-	gtk_window_set_modal (GTK_WINDOW (fileselection), TRUE);
+	filechooser = gtk_file_chooser_dialog_new (_("Save a Copy"),
+						   NULL,
+						   GTK_FILE_CHOOSER_ACTION_SAVE,
+						   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						   GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+						   NULL);
+	gtk_window_set_modal (GTK_WINDOW (filechooser), TRUE);
 	
-	ok_button = GTK_FILE_SELECTION (fileselection)->ok_button;
-	gtk_widget_show (ok_button);
-	GTK_WIDGET_SET_FLAGS (ok_button, GTK_CAN_DEFAULT);
-	
-	cancel_button = GTK_FILE_SELECTION (fileselection)->cancel_button;
-	gtk_widget_show (cancel_button);
-	GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
+	gtk_dialog_set_default_response (GTK_DIALOG (filechooser), GTK_RESPONSE_OK);
 
-	bonobo_control_set_transient_for(control,
-					 GTK_WINDOW (fileselection),
-					 NULL);
-	gtk_widget_show (fileselection);
+	bonobo_control_set_transient_for (control,
+					  GTK_WINDOW (filechooser),
+					  NULL);
+	gtk_widget_show (filechooser);
 
-	if (gtk_dialog_run(GTK_DIALOG (fileselection)) == GTK_RESPONSE_OK)
-		pathname = (gchar *)g_strdup (
-			gtk_file_selection_get_filename(
-				GTK_FILE_SELECTION (fileselection)));
+	if (gtk_dialog_run(GTK_DIALOG (filechooser)) == GTK_RESPONSE_OK)
+		pathname = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filechooser));
 
-	gtk_widget_destroy (fileselection); 
+	gtk_widget_destroy (filechooser); 
 	
 	return pathname; 
 }
@@ -945,7 +937,6 @@ gc_ui_set_pixbufs (GPdfControl *control)
 	BonoboUIComponent *ui_component;
 	GtkIconSet *icon_set;
 	GdkPixbuf *pixbuf, *menu_pixbuf;
-	gchar *pixbuf_xml, *menu_pixbuf_xml;
 
 	gpdf_view = control->priv->gpdf_view;
 
@@ -1428,7 +1419,6 @@ gpdf_control_constructor (GType type,
 	GObject *object;
 	GPdfControl *control;
 	GPdfControlPrivate *priv;
-	guint i;
 
 	object = G_OBJECT_CLASS (parent_class)->constructor (
 		type, n_construct_properties, construct_params);
