@@ -16,7 +16,6 @@
 #include "gpdf-g-switch.h"
 #  include <libbonobo.h>
 #  include <libbonoboui.h>
-#  include <libgnomeui/gnome-stock-icons.h>
 #  include <gtk/gtk.h>
 #include "gpdf-g-switch.h"
 #include "Object.h"
@@ -101,7 +100,6 @@ gpdf_persist_file_on_cancelbutton_clicked (GtkButton *button,
 					   gpointer   user_data)
 {
     GtkWidget *dialog1 = GTK_WIDGET (user_data);
-    GtkWidget *entry1 = GTK_WIDGET (g_object_get_data (G_OBJECT (dialog1), "entry1"));
 
     gtk_widget_hide (dialog1);
     g_object_set_data (G_OBJECT (dialog1), "passwd", (gpointer)"");
@@ -135,7 +133,6 @@ gpdf_persist_file_create_password_dialog (const gchar *labeltext,
     GtkWidget *label;
     GtkWidget *entry1;
     GtkWidget *dialog_action_area1;
-    GtkWidget *helpbutton1;
     GtkWidget *cancelbutton1;
     GtkWidget *okbutton1;
     GtkTooltips *tooltips;
@@ -163,7 +160,7 @@ gpdf_persist_file_create_password_dialog (const gchar *labeltext,
 
     image = gtk_widget_new (GTK_TYPE_IMAGE,
 			    /* FIXME use gtk stock icon from gtk 2.3 */
-			    "stock", GNOME_STOCK_AUTHENTICATION,
+			    "stock", GTK_STOCK_DIALOG_AUTHENTICATION,
 			    "icon-size", GTK_ICON_SIZE_DIALOG,
 			    "yalign", 0.0,
 			    NULL);
